@@ -315,6 +315,29 @@ impl<'de, 'a, 'b, 's, 'x> de::Deserializer<'de>
       return visitor.visit_bytes(&data);
     }
 
+    // Magic ByteString
+    if name == magic::bytestring::NAME {
+      if let Some(v8_string) = self.input.to_string(self.scope) {
+        if v8_string.contains_only_onebyte() {
+          let mut buffer: Vec<u8> = vec![0u8; v8_string.length()];
+          let written = v8_string.write_one_byte(
+            self.scope,
+            &mut buffer,
+            0,
+            v8::WriteOptions::NO_NULL_TERMINATION,
+          );
+          assert!(written == v8_string.length());
+          return visitor.visit_byte_buf(buffer);
+        } else {
+          return Err(Error::Message(
+            "Expected a valid ByteString.".to_string(),
+          ));
+        }
+      } else {
+        return Err(Error::ExpectedString);
+      }
+    }
+
     // Regular struct
     let obj = v8::Local::<v8::Object>::try_from(self.input).unwrap();
     let map = ObjectAccess {
